@@ -2,4 +2,4 @@ from datetime import datetime
 
 #-------------------------------------------------------------------------------
 def current_datetime(request):
-    return dict(current_datetime=datetime.now())
\ No newline at end of file
+    return {'current_datetime': datetime.now()}
\ No newline at end of file
