@@ -2,6 +2,7 @@ from datetime import datetime, date, timedelta
 from dateutil import rrule
 
 from django.utils.translation import ugettext_lazy as _
+from django.utils.encoding import python_2_unicode_compatible
 from django.contrib.contenttypes.models import ContentType
 from django.db import models
 from django.contrib.auth.models import User
@@ -22,6 +23,7 @@ __all__ = (
 )
 
 #===============================================================================
+@python_2_unicode_compatible
 class Note(models.Model):
     '''
     A generic model for adding simple, arbitrary notes to other models such as
@@ -41,17 +43,18 @@ class Note(models.Model):
         verbose_name_plural = _('notes')
         
     #---------------------------------------------------------------------------
-    def __unicode__(self):
+    def __str__(self):
         return self.note
 
 
 #===============================================================================
+@python_2_unicode_compatible
 class EventType(models.Model):
     '''
     Simple ``Event`` classifcation.
     
     '''
-    abbr = models.CharField(_(u'abbreviation'), max_length=4, unique=True)
+    abbr = models.CharField(_('abbreviation'), max_length=4, unique=True)
     label = models.CharField(_('label'), max_length=50)
 
     #===========================================================================
@@ -60,11 +63,12 @@ class EventType(models.Model):
         verbose_name_plural = _('event types')
         
     #---------------------------------------------------------------------------
-    def __unicode__(self):
+    def __str__(self):
         return self.label
 
 
 #===============================================================================
+@python_2_unicode_compatible
 class Event(models.Model):
     '''
     Container model for general metadata and associated ``Occurrence`` entries.
@@ -81,7 +85,7 @@ class Event(models.Model):
         ordering = ('title', )
         
     #---------------------------------------------------------------------------
-    def __unicode__(self):
+    def __str__(self):
         return self.title
 
     #---------------------------------------------------------------------------
@@ -178,6 +182,7 @@ class OccurrenceManager(models.Manager):
 
 
 #===============================================================================
+@python_2_unicode_compatible
 class Occurrence(models.Model):
     '''
     Represents the start end time for a specific occurrence of a master ``Event``
@@ -197,8 +202,8 @@ class Occurrence(models.Model):
         ordering = ('start_time', 'end_time')
 
     #---------------------------------------------------------------------------
-    def __unicode__(self):
-        return u'%s: %s' % (self.title, self.start_time.isoformat())
+    def __str__(self):
+        return '%s: %s' % (self.title, self.start_time.isoformat())
 
     #---------------------------------------------------------------------------
     @models.permalink
@@ -206,8 +211,8 @@ class Occurrence(models.Model):
         return ('swingtime-occurrence', [str(self.event.id), str(self.id)])
 
     #---------------------------------------------------------------------------
-    def __cmp__(self, other):
-        return cmp(self.start_time, other.start_time)
+    def __lt__(self, other):
+        return self.start_time < other.start_time
 
     #---------------------------------------------------------------------------
     @property
